@@ -1,5 +1,5 @@
 package App::Notifier::Client::Notifier_App;
-$App::Notifier::Client::Notifier_App::VERSION = '0.0400';
+$App::Notifier::Client::Notifier_App::VERSION = '0.0401';
 use strict;
 use warnings;
 
@@ -10,7 +10,7 @@ use Pod::Usage;
 
 use YAML::XS qw( LoadFile );
 
-use App::Notifier::Client;
+use App::Notifier::Client ();
 
 
 sub new
@@ -153,11 +153,12 @@ __END__
 
 =head1 NAME
 
-App::Notifier::Client::Notifier_App
+App::Notifier::Client::Notifier_App - implements the notifier command-line
+app.
 
 =head1 VERSION
 
-version 0.0400
+version 0.0401
 
 =head1 SYNOPSIS
 
@@ -168,11 +169,6 @@ version 0.0400
 
     App::Notifier::Client::Notifier_App->new({argv => [@ARGV],})->run();
 
-=head1 NAME
-
-App::Notifier::Client::Notifier_App - implements the notifier command-line
-app.
-
 =head1 FUNCTIONS
 
 =head2 new({argv => [@ARGV]})
@@ -221,10 +217,98 @@ WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 OTHER DEALINGS IN THE SOFTWARE.
 
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+
+=head1 SUPPORT
+
+=head2 Websites
+
+The following websites have more information about this module, and may be of help to you. As always,
+in addition to those websites please use your favorite search engine to discover more resources.
+
+=over 4
+
+=item *
+
+MetaCPAN
+
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
+
+L<https://metacpan.org/release/App-Notifier-Client>
+
+=item *
+
+RT: CPAN's Bug Tracker
+
+The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
+
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-Notifier-Client>
+
+=item *
+
+CPANTS
+
+The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
+
+L<http://cpants.cpanauthors.org/dist/App-Notifier-Client>
+
+=item *
+
+CPAN Testers
+
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
+
+L<http://www.cpantesters.org/distro/A/App-Notifier-Client>
+
+=item *
+
+CPAN Testers Matrix
+
+The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
+
+L<http://matrix.cpantesters.org/?dist=App-Notifier-Client>
+
+=item *
+
+CPAN Testers Dependencies
+
+The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
+
+L<http://deps.cpantesters.org/?module=App::Notifier::Client>
+
+=back
+
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests by email to C<bug-app-notifier-client at rt.cpan.org>, or through
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=App-Notifier-Client>. You will be automatically notified of any
+progress on the request by the system.
+
+=head2 Source Code
+
+The code is open to the world, and available for you to hack on. Please feel free to browse it and play
+with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
+from your repository :)
+
+L<https://github.com/shlomif/app-notifier>
+
+  git clone git://github.com/shlomif/app-notifier.git
+
 =head1 AUTHOR
 
 Shlomi Fish <shlomif@cpan.org>
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=App-Notifier-Client> or by email
+to
+L<bug-app-notifier-client@rt.cpan.org|mailto:bug-app-notifier-client@rt.cpan.org>.
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2012 by Shlomi Fish.
